==> qtjambi-opengl-6.5.4-sources.jar: io/qt/opengl/QOpenGLVersionProfile.java <==
package io.qt.opengl;

import io.qt.*;


/**
 * <p>Represents the version and if applicable the profile of an OpenGL context</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html">QOpenGLVersionProfile</a></code></p>
 */
public class QOpenGLVersionProfile extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#QOpenGLVersionProfile">QOpenGLVersionProfile::<wbr/>QOpenGLVersionProfile()</a></code></p>
     */
    public QOpenGLVersionProfile(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QOpenGLVersionProfile instance);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#QOpenGLVersionProfile-2">QOpenGLVersionProfile::<wbr/>QOpenGLVersionProfile(QOpenGLVersionProfile)</a></code></p>
     */
    public QOpenGLVersionProfile(io.qt.opengl.@NonNull QOpenGLVersionProfile other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QOpenGLVersionProfile instance, io.qt.opengl.QOpenGLVersionProfile other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#QOpenGLVersionProfile-1">QOpenGLVersionProfile::<wbr/>QOpenGLVersionProfile(QSurfaceFormat)</a></code></p>
     */
    public QOpenGLVersionProfile(io.qt.gui.@NonNull QSurfaceFormat format){
        super((QPrivateConstructor)null);
        initialize_native(this, format);
    }
    
    private native static void initialize_native(QOpenGLVersionProfile instance, io.qt.gui.QSurfaceFormat format);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#hasProfiles">QOpenGLVersionProfile::<wbr/>hasProfiles()const</a></code></p>
     */
    @QtUninvokable
    public final boolean hasProfiles(){
        return hasProfiles_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasProfiles_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#isLegacyVersion">QOpenGLVersionProfile::<wbr/>isLegacyVersion()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isLegacyVersion(){
        return isLegacyVersion_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isLegacyVersion_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#isValid">QOpenGLVersionProfile::<wbr/>isValid()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#operator-eq">QOpenGLVersionProfile::<wbr/>operator=(QOpenGLVersionProfile)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.opengl.@NonNull QOpenGLVersionProfile rhs){
        assign_native_cref_QOpenGLVersionProfile(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QOpenGLVersionProfile(long __this__nativeId, long rhs);
    
    /**
     * <p>See <code>operator==(QOpenGLVersionProfile,<wbr/>QOpenGLVersionProfile)</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.opengl.@NonNull QOpenGLVersionProfile rhs){
        return equals_native_cref_QOpenGLVersionProfile(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QOpenGLVersionProfile(long __this__nativeId, long rhs);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#profile">QOpenGLVersionProfile::<wbr/>profile()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.gui.QSurfaceFormat.@NonNull OpenGLContextProfile profile(){
        return io.qt.gui.QSurfaceFormat.OpenGLContextProfile.resolve(profile_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int profile_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#setProfile">QOpenGLVersionProfile::<wbr/>setProfile(QSurfaceFormat::OpenGLContextProfile)</a></code></p>
     */
    @QtUninvokable
    public final void setProfile(io.qt.gui.QSurfaceFormat.@NonNull OpenGLContextProfile profile){
        setProfile_native_QSurfaceFormat_OpenGLContextProfile(QtJambi_LibraryUtilities.internal.nativeId(this), profile.value());
    }
    
    @QtUninvokable
    private native void setProfile_native_QSurfaceFormat_OpenGLContextProfile(long __this__nativeId, int profile);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#setVersion">QOpenGLVersionProfile::<wbr/>setVersion(int,<wbr/>int)</a></code></p>
     */
    @QtUninvokable
    public final void setVersion(int majorVersion, int minorVersion){
        setVersion_native_int_int(QtJambi_LibraryUtilities.internal.nativeId(this), majorVersion, minorVersion);
    }
    
    @QtUninvokable
    private native void setVersion_native_int_int(long __this__nativeId, int majorVersion, int minorVersion);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#version">QOpenGLVersionProfile::<wbr/>version()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QPair<java.lang.@QtPrimitiveType@NonNull Integer, java.lang.@QtPrimitiveType@NonNull Integer> version(){
        return version_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QPair<java.lang.@QtPrimitiveType Integer, java.lang.@QtPrimitiveType Integer> version_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QOpenGLVersionProfile(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QOpenGLVersionProfile,<wbr/>QOpenGLVersionProfile)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.opengl.QOpenGLVersionProfile) {
            return equals((io.qt.opengl.QOpenGLVersionProfile) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QOpenGLVersionProfile)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    /**
     * <p>See <code>operator&lt;&lt;(QDebug,<wbr/>QOpenGLVersionProfile)</code></p>
     */
    @QtUninvokable
    @Override
    public @NonNull String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QOpenGLVersionProfile clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QOpenGLVersionProfile clone_native(long __this_nativeId);
    
    /**
     * <p>Overloaded constructor for {@link #QOpenGLVersionProfile(io.qt.gui.QSurfaceFormat)}.</p>
     */
    public QOpenGLVersionProfile(io.qt.gui.QSurfaceFormat.@NonNull FormatOptions format) {
        this(new io.qt.gui.QSurfaceFormat(format));
    }
}

==> qtjambi-opengl-6.5.7-sources.jar: io/qt/opengl/QOpenGLVersionProfile.java <==
package io.qt.opengl;

import io.qt.*;


/**
 * <p>Represents the version and if applicable the profile of an OpenGL context</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html">QOpenGLVersionProfile</a></code></p>
 */
public class QOpenGLVersionProfile extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#QOpenGLVersionProfile">QOpenGLVersionProfile::<wbr/>QOpenGLVersionProfile()</a></code></p>
     */
    public QOpenGLVersionProfile(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QOpenGLVersionProfile instance);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#QOpenGLVersionProfile-2">QOpenGLVersionProfile::<wbr/>QOpenGLVersionProfile(QOpenGLVersionProfile)</a></code></p>
     */
    public QOpenGLVersionProfile(io.qt.opengl.@NonNull QOpenGLVersionProfile other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QOpenGLVersionProfile instance, io.qt.opengl.QOpenGLVersionProfile other);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#QOpenGLVersionProfile-1">QOpenGLVersionProfile::<wbr/>QOpenGLVersionProfile(QSurfaceFormat)</a></code></p>
     */
    public QOpenGLVersionProfile(io.qt.gui.@NonNull QSurfaceFormat format){
        super((QPrivateConstructor)null);
        initialize_native(this, format);
    }
    
    private native static void initialize_native(QOpenGLVersionProfile instance, io.qt.gui.QSurfaceFormat format);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#hasProfiles">QOpenGLVersionProfile::<wbr/>hasProfiles()const</a></code></p>
     */
    @QtUninvokable
    public final boolean hasProfiles(){
        return hasProfiles_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasProfiles_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#isLegacyVersion">QOpenGLVersionProfile::<wbr/>isLegacyVersion()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isLegacyVersion(){
        return isLegacyVersion_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isLegacyVersion_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#isValid">QOpenGLVersionProfile::<wbr/>isValid()const</a></code></p>
     */
    @QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#operator-eq">QOpenGLVersionProfile::<wbr/>operator=(QOpenGLVersionProfile)</a></code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.opengl.@NonNull QOpenGLVersionProfile rhs){
        assign_native_cref_QOpenGLVersionProfile(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QOpenGLVersionProfile(long __this__nativeId, long rhs);
    
    /**
     * <p>See <code>operator==(QOpenGLVersionProfile,<wbr/>QOpenGLVersionProfile)</code></p>
     */
    @QtUninvokable
    public final boolean equals(io.qt.opengl.@NonNull QOpenGLVersionProfile rhs){
        return equals_native_cref_QOpenGLVersionProfile(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(rhs));
    }
    
    @QtUninvokable
    private native boolean equals_native_cref_QOpenGLVersionProfile(long __this__nativeId, long rhs);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#profile">QOpenGLVersionProfile::<wbr/>profile()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.gui.QSurfaceFormat.@NonNull OpenGLContextProfile profile(){
        return io.qt.gui.QSurfaceFormat.OpenGLContextProfile.resolve(profile_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int profile_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#setProfile">QOpenGLVersionProfile::<wbr/>setProfile(QSurfaceFormat::OpenGLContextProfile)</a></code></p>
     */
    @QtUninvokable
    public final void setProfile(io.qt.gui.QSurfaceFormat.@NonNull OpenGLContextProfile profile){
        setProfile_native_QSurfaceFormat_OpenGLContextProfile(QtJambi_LibraryUtilities.internal.nativeId(this), profile.value());
    }
    
    @QtUninvokable
    private native void setProfile_native_QSurfaceFormat_OpenGLContextProfile(long __this__nativeId, int profile);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#setVersion">QOpenGLVersionProfile::<wbr/>setVersion(int,<wbr/>int)</a></code></p>
     */
    @QtUninvokable
    public final void setVersion(int majorVersion, int minorVersion){
        setVersion_native_int_int(QtJambi_LibraryUtilities.internal.nativeId(this), majorVersion, minorVersion);
    }
    
    @QtUninvokable
    private native void setVersion_native_int_int(long __this__nativeId, int majorVersion, int minorVersion);
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#version">QOpenGLVersionProfile::<wbr/>version()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QPair<java.lang.@QtPrimitiveType@NonNull Integer, java.lang.@QtPrimitiveType@NonNull Integer> version(){
        return version_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QPair<java.lang.@QtPrimitiveType Integer, java.lang.@QtPrimitiveType Integer> version_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QOpenGLVersionProfile(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QOpenGLVersionProfile,<wbr/>QOpenGLVersionProfile)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other==null || other instanceof io.qt.opengl.QOpenGLVersionProfile) {
            return equals((io.qt.opengl.QOpenGLVersionProfile) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QOpenGLVersionProfile)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);

    /**
     * <p>See <code>operator&lt;&lt;(QDebug,<wbr/>QOpenGLVersionProfile)</code></p>
     */
    @QtUninvokable
    @Override
    public @NonNull String toString() {
        return toString_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private static native String toString_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code><a href="https://doc.qt.io/qt/qopenglversionprofile.html#QOpenGLVersionProfile-2">QOpenGLVersionProfile::<wbr/>QOpenGLVersionProfile(QOpenGLVersionProfile)</a></code></p>
     */
    @QtUninvokable
    @Override
    public QOpenGLVersionProfile clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QOpenGLVersionProfile clone_native(long __this_nativeId);
    
    /**
     * <p>Overloaded constructor for {@link #QOpenGLVersionProfile(io.qt.gui.QSurfaceFormat)}.</p>
     */
    public QOpenGLVersionProfile(io.qt.gui.QSurfaceFormat.@NonNull FormatOptions format) {
        this(new io.qt.gui.QSurfaceFormat(format));
    }
}
